@@ -1,6 +1,4 @@
 package MIME::Decoder::Binary;
-use strict;
-use warnings;
 
 
 =head1 NAME
@@ -27,10 +25,6 @@ read-and-write fixed-size chunks.
 Both the B<encoder> and B<decoder> do a simple pass-through of the data
 from input to output.
 
-=head1 SEE ALSO
-
-L<MIME::Decoder>
-
 
 =head1 AUTHOR
 
@@ -39,6 +33,11 @@ Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
 All rights reserved.  This program is free software; you can redistribute 
 it and/or modify it under the same terms as Perl itself.
 
+
+=head1 VERSION
+
+$Revision: 6.106 $ $Date: 2003/06/04 17:54:02 $
+
 =cut
 
 use MIME::Decoder;
@@ -47,7 +46,7 @@ use vars qw(@ISA $VERSION);
 @ISA = qw(MIME::Decoder);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.517";
+$VERSION = substr q$Revision: 6.106 $, 10;
 
 ### Buffer length:
 my $BUFLEN = 8192;
