@@ -85,7 +85,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision: 6.107 $ $Date: 2003/06/06 23:41:41 $
+$Revision: 6.108 $ $Date: 2003/06/27 17:54:29 $
 
 
 =cut
@@ -99,7 +99,7 @@ use MIME::Tools::Utils qw(:msgs);
 @ISA = qw(MIME::Decoder);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 6.107 $, 10;
+$VERSION = substr q$Revision: 6.108 $, 10;
 
 ### How many bytes to decode at a time?
 my $DecodeChunkLength = 8 * 1024;
@@ -117,11 +117,13 @@ sub decode_it {
 
     ### Get chunks until done:
     while ($in->read($_, $DecodeChunkLength)) {
+
+	### We just read a chunk... tack on until the next EOL:
 	$and_also = $in->getline;
 	$_ .= $and_also if defined($and_also);
 	
-	### Just got a chunk ending in a line.
-	s/\015\012$/\n/g;
+	### We now have a chunk ending in a line.
+	s/\015\012$/\n/g;   ### replace CRLF with local newline (BAD?)
 	$out->print($_);
     }
     1;
