@@ -1,6 +1,5 @@
 package MIME::Decoder::UU;
-use strict;
-use warnings;
+
 
 =head1 NAME
 
@@ -23,9 +22,6 @@ data are uuencoded.  Common non-standard MIME encodings for this:
     x-uu
     x-uuencode
 
-=head1 SEE ALSO
-
-L<MIME::Decoder>
 
 =head1 AUTHOR
 
@@ -37,18 +33,24 @@ unknown author...
 All rights reserved.  This program is free software; you can redistribute 
 it and/or modify it under the same terms as Perl itself.
 
+
+=head1 VERSION
+
+$Revision: 6.107 $ $Date: 2003/06/06 23:41:42 $
+
 =cut
 
 
 require 5.002;
 use vars qw(@ISA $VERSION);
 use MIME::Decoder;
-use MIME::Tools qw(whine);
+use MIME::Tools qw(:msgs);
+use MIME::Tools::Utils qw(:msgs);
 
 @ISA = qw(MIME::Decoder);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.517";
+$VERSION = substr q$Revision: 6.107 $, 10;
 
 
 #------------------------------
@@ -59,6 +61,7 @@ sub decode_it {
     my ($self, $in, $out) = @_;
     my ($mode, $file);
     my @preamble;
+    local $_;
 
     ### Init:
     $self->{MDU_Preamble} = \@preamble;
@@ -66,7 +69,6 @@ sub decode_it {
     $self->{MDU_File} = undef;
 
     ### Find beginning...
-    local $_;
     while (defined($_ = $in->getline)) {
 	if (/^begin(.*)/) {        ### found it: now decode it...
 	    my $modefile = $1;
@@ -91,7 +93,7 @@ sub decode_it {
 	$out->print(unpack('u', $_));
     }
     ### chmod oct($mode), $file;    # sheeyeah... right...
-    whine "file incomplete, no end found\n" if !defined($_); # eof
+    $LOG->warning("file incomplete, no end found\n") if !defined($_); # eof
     1;
 }
 
@@ -106,10 +108,9 @@ sub encode_it {
     my $fname = (($self->head && 
 		  $self->head->mime_attr('content-disposition.filename')) ||
 		 '');
-    my $nl = $MIME::Entity::BOUNDARY_DELIMITER || "\n";
-    $out->print("begin 644 $fname$nl");
+    $out->print("begin 644 $fname\n");
     while ($in->read($buf, 45)) { $out->print(pack('u', $buf)) }
-    $out->print("end$nl");
+    $out->print("end\n");
     1;
 }
 
