@@ -1,6 +1,6 @@
 package MIME::Head;
 
-use MIME::WordDecoder;
+
 =head1 NAME
 
 MIME::Head - MIME message header (a subclass of Mail::Header)
@@ -8,7 +8,7 @@ MIME::Head - MIME message header (a subclass of Mail::Header)
 
 =head1 SYNOPSIS
 
-Before reading further, you should see L<MIME::Tools> to make sure that
+Before reading further, you should see L<MIME::Tools> to make sure that 
 you understand where this module fits into the grand scheme of things.
 Go on, do it now.  I'll wait.
 
@@ -16,14 +16,14 @@ Ready?  Ok...
 
 =head2 Construction
 
-    ### Create a new, empty header, and populate it manually:
+    ### Create a new, empty header, and populate it manually:    
     $head = MIME::Head->new;
     $head->replace('content-type', 'text/plain; charset=US-ASCII');
     $head->replace('content-length', $len);
-
+    
     ### Parse a new header from a filehandle:
     $head = MIME::Head->read(\*STDIN);
-
+    
     ### Parse a new header from a file, or a readable pipe:
     $testhead = MIME::Head->from_file("/tmp/test.hdr");
     $a_b_head = MIME::Head->from_file("cat a.hdr b.hdr |");
@@ -32,8 +32,8 @@ Ready?  Ok...
 =head2 Output
 
     ### Output to filehandle:
-    $head->print(\*STDOUT);
-
+    $head->print(\*STDOUT);  
+    
     ### Output as string:
     print STDOUT $head->as_string;
     print STDOUT $head->stringify;
@@ -43,17 +43,17 @@ Ready?  Ok...
 
     ### Is this a reply?
     $is_reply = 1 if ($head->get('Subject') =~ /^Re: /);
-
+    
     ### Get receipt information:
-    print "Last received from: ", $head->get('Received', 0);
+    print "Last received from: ", $head->get('Received', 0), "\n";
     @all_received = $head->get('Received');
-
+    
     ### Print the subject, or the empty string if none:
-    print "Subject: ", $head->get('Subject',0);
-
+    print "Subject: ", $head->get('Subject',0), "\n";
+     
     ### Too many hops?  Count 'em and see!
     if ($head->count('Received') > 5) { ...
-
+    
     ### Test whether a given field exists
     warn "missing subject!" if (! $head->count('subject'));
 
@@ -68,10 +68,8 @@ Ready?  Ok...
 
     ### Get rid of internal newlines in fields:
     $head->unfold;
-
-    ### Decode any Q- or B-encoded-text in fields (DEPRECATED):
-    $head->decode;
-
+    
+    
 
 =head2 Getting high-level MIME information
 
@@ -82,23 +80,22 @@ Ready?  Ok...
 
     ### The content type (e.g., "text/html"):
     $mime_type     = $head->mime_type;
-
+    
     ### The content transfer encoding (e.g., "quoted-printable"):
     $mime_encoding = $head->mime_encoding;
-
+    
     ### The recommended name when extracted:
     $file_name     = $head->recommended_filename;
-
+    
     ### The boundary text, for multipart messages:
     $boundary      = $head->multipart_boundary;
 
 
 =head1 DESCRIPTION
 
-A class for parsing in and manipulating RFC-822 message headers, with
-some methods geared towards standard (and not so standard) MIME fields
-as specified in the various I<Multipurpose Internet Mail Extensions>
-RFCs (starting with RFC 2045)
+A class for parsing in and manipulating RFC-822 message headers, with some 
+methods geared towards standard (and not so standard) MIME fields as 
+specified in RFC-1521, I<Multipurpose Internet Mail Extensions>.
 
 
 =head1 PUBLIC INTERFACE
@@ -114,7 +111,7 @@ use strict;
 use vars qw($VERSION @ISA @EXPORT_OK);
 
 ### System modules:
-use IO::File;
+use IO::Wrap;
 
 ### Other modules:
 use Mail::Header 1.09 ();
@@ -123,6 +120,7 @@ use Mail::Field  1.05 ();
 ### Kit modules:
 use MIME::Words qw(:all);
 use MIME::Tools qw(:config :msgs);
+use MIME::Tools::Utils qw(:config :msgs);
 use MIME::Field::ParamVal;
 use MIME::Field::ConTraEnc;
 use MIME::Field::ContDisp;
@@ -130,27 +128,6 @@ use MIME::Field::ContType;
 
 @ISA = qw(Mail::Header);
 
-# The presence of more than one of the following headers
-# in a given MIME entity could indicate an ambiguous parse
-# and hence a security risk
-
-my $singleton_headers =
-    [
-     'content-type',
-     'content-disposition',
-     'content-transfer-encoding',
-     'content-id',
-    ];
-
-# The presence of a duplicated or empty parameters in one of the following
-# headers in a given MIME entity could indicate an ambiguous parse and
-# hence a security risk
-my $singleton_parameter_headers =
-    [
-     'content-type',
-     'content-disposition',
-    ];
-
 
 #------------------------------
 #
@@ -159,7 +136,7 @@ my $singleton_parameter_headers =
 #------------------------------
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.516";
+$VERSION = substr q$Revision: 6.107 $, 10;
 
 ### Sanity (we put this test after our own version, for CPAN::):
 use Mail::Header 1.06 ();
@@ -181,8 +158,8 @@ use Mail::Header 1.06 ();
 =item new [ARG],[OPTIONS]
 
 I<Class method, inherited.>
-Creates a new header object.  Arguments are the same as those in the
-superclass.
+Creates a new header object.  Arguments are the same as those in the 
+superclass.  
 
 =cut
 
@@ -191,60 +168,20 @@ sub new {
     bless Mail::Header->new(@_), $class;
 }
 
-=item ambiguous_content
-
-I<Instance method.>
-
-Returns true if this header has any the following properties:
-
-=over 4
-
-More than one Content-Type, Content-ID, Content-Transfer-Encoding or
-Content-Disposition header.
-
-A Content-Type or Content-Disposition header contains a repeated
-parameter.
-
-=back
-
-Messages with ambiguous content should be treated as a security risk.
-In particular, if MIME-tools is used in an email security tool,
-ambiguous messages should not be delivered to end-users.
-
-=cut
-sub ambiguous_content {
-    my ($self) = @_;
-
-    foreach my $hdr (@$singleton_headers) {
-        if ($self->count($hdr) > 1) {
-            return 1;
-        }
-    }
-
-    foreach my $hdr (@$singleton_parameter_headers) {
-        if ($self->mime_attr($hdr . '.@duplicate_parameters')) {
-            return 1;
-        }
-        if ($self->mime_attr($hdr . '.@empty_parameters')) {
-            return 1;
-        }
-    }
-    return 0;
-}
 #------------------------------
 
 =item from_file EXPR,OPTIONS
 
 I<Class or instance method>.
-For convenience, you can use this to parse a header object in from EXPR,
-which may actually be any expression that can be sent to open() so as to
-return a readable filehandle.  The "file" will be opened, read, and then
+For convenience, you can use this to parse a header object in from EXPR, 
+which may actually be any expression that can be sent to open() so as to 
+return a readable filehandle.  The "file" will be opened, read, and then 
 closed:
 
     ### Create a new header by parsing in a file:
     my $head = MIME::Head->from_file("/tmp/test.hdr");
 
-Since this method can function as either a class constructor I<or>
+Since this method can function as either a class constructor I<or> 
 an instance initializer, the above is exactly equivalent to:
 
     ### Create a new header by parsing in a file:
@@ -265,10 +202,10 @@ sub from_file {
     my $class = ref($self) ? ref($self) : $self;
 
     ### Parse:
-    my $fh = IO::File->new($file, '<') or return error("open $file: $!");
-    $fh->binmode() or return error("binmode $file: $!");  # we expect to have \r\n at line ends, and want to keep 'em.
-    $self = $class->new($fh, @opts);      ### now, $self is instance or undef
-    $fh->close or return error("close $file: $!");
+    open(HDR, $file) or die "can't open $file: $!\n";
+    binmode(HDR);  # we expect to have \r\n at line ends, and want to keep 'em.
+    $self = $class->new(\*HDR, @opts);      ### now, $self is instance or undef
+    close(HDR);
     $self;
 }
 
@@ -276,9 +213,9 @@ sub from_file {
 
 =item read FILEHANDLE
 
-I<Instance (or class) method.>
-This initializes a header object by reading it in from a FILEHANDLE,
-until the terminating blank line is encountered.
+I<Instance (or class) method.> 
+This initiallizes a header object by reading it in from a FILEHANDLE,
+until the terminating blank line is encountered.  
 A syntax error or end-of-stream will also halt processing.
 
 Supply this routine with a reference to a filehandle glob; e.g., C<\*STDIN>:
@@ -302,7 +239,7 @@ into account.
 sub read {
     my $self = shift;      ### either instance or class!
     ref($self) or $self = $self->new;    ### if used as class method, make new
-    $self->SUPER::read(@_);
+    $self->SUPER::read(@_);   
 }
 
 
@@ -313,7 +250,7 @@ sub read {
 
 =head2 Getting/setting fields
 
-The following are methods related to retrieving and modifying the header
+The following are methods related to retrieving and modifying the header 
 fields.  Some are inherited from Mail::Header, but I've kept the
 documentation around for convenience.
 
@@ -329,44 +266,32 @@ documentation around for convenience.
 =item add TAG,TEXT,[INDEX]
 
 I<Instance method, inherited.>
-Add a new occurrence of the field named TAG, given by TEXT:
+Add a new occurence of the field named TAG, given by TEXT:
 
-    ### Add the trace information:
-    $head->add('Received',
+    ### Add the trace information:    
+    $head->add('Received', 
                'from eryq.pr.mcs.net by gonzo.net with smtp');
 
-Normally, the new occurrence will be I<appended> to the existing
-occurrences.  However, if the optional INDEX argument is 0, then the
-new occurrence will be I<prepended>.  If you want to be I<explicit>
+Normally, the new occurence will be I<appended> to the existing 
+occurences.  However, if the optional INDEX argument is 0, then the 
+new occurence will be I<prepended>.  If you want to be I<explicit> 
 about appending, specify an INDEX of -1.
 
-B<Warning>: this method always adds new occurrences; it doesn't overwrite
-any existing occurrences... so if you just want to I<change> the value
-of a field (creating it if necessary), then you probably B<don't> want to use
+B<Warning>: this method always adds new occurences; it doesn't overwrite
+any existing occurences... so if you just want to I<change> the value
+of a field (creating it if necessary), then you probably B<don't> want to use 
 this method: consider using C<replace()> instead.
 
 =cut
 
 ### Inherited.
 
-#------------------------------
-#
-# copy
-#
-# Instance method, DEPRECATED.
-# Duplicate the object.
-#
-sub copy {
-    usage "deprecated: use dup() instead.";
-    shift->dup(@_);
-}
-
 #------------------------------
 
 =item count TAG
 
 I<Instance method, inherited.>
-Returns the number of occurrences of a field; in a boolean context, this
+Returns the number of occurences of a field; in a boolean context, this
 tells you whether a given field exists:
 
     ### Was a "Subject:" field given?
@@ -380,88 +305,14 @@ and some true value if it does.
 
 ### Inherited.
 
-
 #------------------------------
-
-=item decode [FORCE]
-
-I<Instance method, DEPRECATED.>
-Go through all the header fields, looking for RFC 1522 / RFC 2047 style
-"Q" (quoted-printable, sort of) or "B" (base64) encoding, and decode
-them in-place.  Fellow Americans, you probably don't know what the hell
-I'm talking about.  Europeans, Russians, et al, you probably do.
-C<:-)>.
-
-B<This method has been deprecated.>
-See L<MIME::Parser/decode_headers> for the full reasons.
-If you absolutely must use it and don't like the warning, then
-provide a FORCE:
-
-   "I_NEED_TO_FIX_THIS"
-          Just shut up and do it.  Not recommended.
-          Provided only for those who need to keep old scripts functioning.
-
-   "I_KNOW_WHAT_I_AM_DOING"
-          Just shut up and do it.  Not recommended.
-          Provided for those who REALLY know what they are doing.
-
-B<What this method does.>
-For an example, let's consider a valid email header you might get:
-
-    From: =?US-ASCII?Q?Keith_Moore?= <moore@cs.utk.edu>
-    To: =?ISO-8859-1?Q?Keld_J=F8rn_Simonsen?= <keld@dkuug.dk>
-    CC: =?ISO-8859-1?Q?Andr=E9_?= Pirard <PIRARD@vm1.ulg.ac.be>
-    Subject: =?ISO-8859-1?B?SWYgeW91IGNhbiByZWFkIHRoaXMgeW8=?=
-     =?ISO-8859-2?B?dSB1bmRlcnN0YW5kIHRoZSBleGFtcGxlLg==?=
-     =?US-ASCII?Q?.._cool!?=
-
-That basically decodes to (sorry, I can only approximate the
-Latin characters with 7 bit sequences /o and 'e):
-
-    From: Keith Moore <moore@cs.utk.edu>
-    To: Keld J/orn Simonsen <keld@dkuug.dk>
-    CC: Andr'e  Pirard <PIRARD@vm1.ulg.ac.be>
-    Subject: If you can read this you understand the example... cool!
-
-B<Note:> currently, the decodings are done without regard to the
-character set: thus, the Q-encoding C<=F8> is simply translated to the
-octet (hexadecimal C<F8>), period.  For piece-by-piece decoding
-of a given field, you want the array context of
-C<MIME::Words::decode_mimewords()>.
-
-B<Warning:> the CRLF+SPACE separator that splits up long encoded words
-into shorter sequences (see the Subject: example above) gets lost
-when the field is unfolded, and so decoding after unfolding causes
-a spurious space to be left in the field.
-I<THEREFORE: if you're going to decode, do so BEFORE unfolding!>
-
-This method returns the self object.
-
-I<Thanks to Kent Boortz for providing the idea, and the baseline
-RFC-1522-decoding code.>
-
-=cut
-
+#
+# decode
+#
+# Instance method, deprecated.
+#
 sub decode {
-    my $self = shift;
-
-    ### Warn if necessary:
-    my $force = shift || 0;
-    unless (($force eq "I_NEED_TO_FIX_THIS") ||
-	    ($force eq "I_KNOW_WHAT_I_AM_DOING")) {
-	usage "decode is deprecated for safety";
-    }
-
-    my ($tag, $i, @decoded);
-    foreach $tag ($self->tags) {
-	@decoded = map { scalar(decode_mimewords($_, Field=>$tag))
-			 } $self->get_all($tag);
-	for ($i = 0; $i < @decoded; $i++) {
-	    $self->replace($tag, $decoded[$i], $i);
-	}
-    }
-    $self->{MH_Decoded} = 1;
-    $self;
+    usage_error "deprecated MIME::Head::decode() has been removed";
 }
 
 #------------------------------
@@ -469,7 +320,7 @@ sub decode {
 =item delete TAG,[INDEX]
 
 I<Instance method, inherited.>
-Delete all occurrences of the field named TAG.
+Delete all occurences of the field named TAG.
 
     ### Remove some MIME information:
     $head->delete('MIME-Version');
@@ -480,37 +331,19 @@ Delete all occurrences of the field named TAG.
 ### Inherited
 
 
-#------------------------------
-#
-# exists
-#
-sub exists {
-    usage "deprecated; use count() instead";
-    shift->count(@_);
-}
-
-#------------------------------
-#
-# fields
-#
-sub fields {
-    usage "deprecated: use tags() instead",
-    shift->tags(@_);
-}
-
 #------------------------------
 
 =item get TAG,[INDEX]
 
-I<Instance method, inherited.>
+I<Instance method, inherited.>  
 Get the contents of field TAG.
 
-If a B<numeric INDEX> is given, returns the occurrence at that index,
+If a B<numeric INDEX> is given, returns the occurence at that index, 
 or undef if not present:
 
     ### Print the first and last 'Received:' entries (explicitly):
-    print "First, or most recent: ", $head->get('received', 0);
-    print "Last, or least recent: ", $head->get('received',-1);
+    print "First, or most recent: ", $head->get('received', 0), "\n";
+    print "Last, or least recent: ", $head->get('received',-1), "\n"; 
 
 If B<no INDEX> is given, but invoked in a B<scalar> context, then
 INDEX simply defaults to 0:
@@ -519,14 +352,11 @@ INDEX simply defaults to 0:
     my $most_recent = $head->get('received');
 
 If B<no INDEX> is given, and invoked in an B<array> context, then
-I<all> occurrences of the field are returned:
+I<all> occurences of the field are returned:
 
     ### Get all 'Received:' entries:
     my @all_received = $head->get('received');
 
-B<NOTE>: The header(s) returned may end with a newline.  If you don't
-want this, then B<chomp> the return value.
-
 =cut
 
 ### Inherited.
@@ -537,21 +367,21 @@ want this, then B<chomp> the return value.
 =item get_all FIELD
 
 I<Instance method.>
-Returns the list of I<all> occurrences of the field, or the
+Returns the list of I<all> occurences of the field, or the 
 empty list if the field is not present:
 
     ### How did it get here?
     @history = $head->get_all('Received');
 
-B<Note:> I had originally experimented with having C<get()> return all
-occurrences when invoked in an array context... but that causes a lot of
+B<Note:> I had originally experimented with having C<get()> return all 
+occurences when invoked in an array context... but that causes a lot of 
 accidents when you get careless and do stuff like this:
 
-    print "\u$field: ", $head->get($field);
+    print "\u$field: ", $head->get($field), "\n";
 
-It also made the intuitive behaviour unclear if the INDEX argument
+It also made the intuitive behaviour unclear if the INDEX argument 
 was given in an array context.  So I opted for an explicit approach
-to asking for all occurrences.
+to asking for all occurences.
 
 =cut
 
@@ -561,18 +391,6 @@ sub get_all {
     ($self->get($tag));
 }
 
-#------------------------------
-#
-# original_text
-#
-# Instance method, DEPRECATED.
-# Return an approximation of the original text.
-#
-sub original_text {
-    usage "deprecated: use stringify() instead";
-    shift->stringify(@_);
-}
-
 #------------------------------
 
 =item print [OUTSTREAM]
@@ -592,23 +410,10 @@ Also, it defaults to the I<currently-selected> filehandle if none is given
 
 sub print {
     my ($self, $fh) = @_;
-    $fh ||= select;
+    $fh = wraphandle($fh || select);   ### get output handle, as a print()able
     $fh->print($self->as_string);
 }
 
-#------------------------------
-#
-# set TAG,TEXT
-#
-# Instance method, DEPRECATED.
-# Set the field named TAG to [the single occurrence given by the TEXT.
-#
-sub set {
-    my $self = shift;
-    usage "deprecated: use the replace() method instead.";
-    $self->replace(@_);
-}
-
 #------------------------------
 
 =item stringify
@@ -616,17 +421,12 @@ sub set {
 I<Instance method.>
 Return the header as a string.  You can also invoke it as C<as_string>.
 
-If you set the variable $MIME::Entity::BOUNDARY_DELIMITER to a string,
-that string will be used as line-end delimiter.  If it is not set,
-the line ending will be a newline character (\n)
-
 =cut
 
 sub stringify {
     my $self = shift;          ### build clean header, and output...
     my @header = grep {defined($_) ? $_ : ()} @{$self->header};
-    my $header_delimiter = $MIME::Entity::BOUNDARY_DELIMITER || "\n";
-    join "", map { /\n$/ ? substr($_, 0, -1) . $header_delimiter : $_ . $header_delimiter } @header;
+    join "", map { /\n$/ ? $_ : "$_\n" } @header;
 }
 sub as_string { shift->stringify(@_) }
 
@@ -635,7 +435,7 @@ sub as_string { shift->stringify(@_) }
 =item unfold [FIELD]
 
 I<Instance method, inherited.>
-Unfold (remove newlines in) the text of all occurrences of the given FIELD.
+Unfold (remove newlines in) the text of all occurences of the given FIELD.  
 If the FIELD is omitted, I<all> fields are unfolded.
 Returns the "self" object.
 
@@ -658,7 +458,7 @@ All of the following methods extract information from the following fields:
 
 Be aware that they do not just return the raw contents of those fields,
 and in some cases they will fill in sensible (I hope) default values.
-Use C<get()> or C<mime_attr()> if you need to grab and process the
+Use C<get()> or C<mime_attr()> if you need to grab and process the 
 raw field text.
 
 B<Note:> some of these methods are provided both as a convenience and
@@ -674,27 +474,9 @@ field, you should really use the Mail::Field interface to get it.
 
 #------------------------------
 
-
-#------------------------------
-#
-# params TAG
-#
-# Instance method, DEPRECATED.
-# Extract parameter info from a structured field, and return
-# it as a hash reference.  Provided for 1.0 compatibility only!
-# Use the new MIME::Field interface classes (subclasses of Mail::Field).
-
-sub params {
-    my ($self, $tag) = @_;
-    usage "deprecated: use the MIME::Field interface classes from now on!";
-    return MIME::Field::ParamVal->parse_params($self->get($tag,0));
-}
-
-#------------------------------
-
 =item mime_attr ATTR,[VALUE]
 
-A quick-and-easy interface to set/get the attributes in structured
+A quick-and-easy interface to set/get the attributes in structured 
 MIME fields:
 
     $head->mime_attr("content-type"         => "text/html");
@@ -705,10 +487,10 @@ This would cause the final output to look something like this:
 
     Content-type: text/html; charset=US-ASCII; name="homepage.html"
 
-Note that the special empty sub-field tag indicates the anonymous
+Note that the special empty sub-field tag indicates the anonymous 
 first sub-field.
 
-B<Giving VALUE as undefined> will cause the contents of the named subfield
+B<Giving VALUE as undefined> will cause the contents of the named subfield 
 to be deleted:
 
     $head->mime_attr("content-type.charset" => undef);
@@ -721,46 +503,6 @@ or undefined if it isn't there:
 
 In all cases, the new/current value is returned.
 
-The special sub-field tag C<@duplicate_parameters> (which can never be
-a real tag) returns an arrayref of tags that were duplicated in the header,
-or C<undef> if no such tags were found.  For example, given the header:
-
-    Content-Type: multipart/mixed; boundary="foo"; boundary="bar"
-
-Then:
-
-    $head->mime_attr('content-type.@duplicate_parameters')
-
-would return:
-
-    [ 'boundary' ]
-
-Similarly he special sub-field tag C<@empty_parameters> (which can never be
-a real tag) returns an arrayref of tags that had an empty parameter value
-in the header, or C<undef> if no such tags were found. For example, given
-the header:
-
-    Content-Type: multipart/mixed; boundary=;
-
-Then:
-
-    $head->mime_attr('content-type.@emtpy_parameters')
-
-would return:
-
-    [ 'boundary' ]
-
-A duplicate or empty "boundary" tag should be treated as a security risk, as
-should duplicate Content-Type headers in a message.  Since such messages
-cannot be parsed unambiguously, we strongly recommend that they never be
-delivered to end-users.
-
-Note also that a parameter explicitly set to blank via something like:
-
-    Content-Type: application/octet-stream; boundary=""
-
-I<will> populate C<@empty_parameters>
-
 =cut
 
 sub mime_attr {
@@ -790,13 +532,13 @@ I<Instance method.>
 Try I<real hard> to determine the content transfer encoding
 (e.g., C<"base64">, C<"binary">), which is returned in all-lowercase.
 
-If no encoding could be found, the default of C<"7bit"> is returned
-I quote from RFC 2045 section 6.1:
+If no encoding could be found, the default of C<"7bit"> is returned.  
+I quote from RFC-1521 section 5:
 
-    This is the default value -- that is, "Content-Transfer-Encoding: 7BIT"
+    This is the default value -- that is, "Content-Transfer-Encoding: 7BIT" 
     is assumed if the Content-Transfer-Encoding header field is not present.
 
-I do one other form of fixup: "7_bit", "7-bit", and "7 bit" are
+I do one other form of fixup: "7_bit", "7-bit", and "7 bit" are 
 corrected to "7bit"; likewise for "8bit".
 
 =cut
@@ -814,21 +556,16 @@ sub mime_encoding {
 
 I<Instance method.>
 Try C<real hard> to determine the content type (e.g., C<"text/plain">,
-C<"image/gif">, C<"x-weird-type">, which is returned in all-lowercase.
-"Real hard" means that if no content type could be found, the default
-(usually C<"text/plain">) is returned.  From RFC 2045 section 5.2:
+C<"image/gif">, C<"x-weird-type">, which is returned in all-lowercase.  
+"Real hard" means that if no content type could be found, the default 
+(usually C<"text/plain">) is returned.  From RFC-1521 section 7.1:
 
-   Default RFC 822 messages without a MIME Content-Type header are
-   taken by this protocol to be plain text in the US-ASCII character
-   set, which can be explicitly specified as:
+    The default Content-Type for Internet mail is 
+    "text/plain; charset=us-ascii".
 
-      Content-type: text/plain; charset=us-ascii
-
-   This default is assumed if no Content-Type header field is specified.
-
-Unless this is a part of a "multipart/digest", in which case
-"message/rfc822" is the default.  Note that you can also I<set> the
-default, but you shouldn't: normally only the MIME parser uses this
+Unless this is a part of a "multipart/digest", in which case 
+"message/rfc822" is the default.  Note that you can also I<set> the 
+default, but you shouldn't: normally only the MIME parser uses this 
 feature.
 
 =cut
@@ -836,13 +573,9 @@ feature.
 sub mime_type {
     my ($self, $default) = @_;
     $self->{MIH_DefaultType} = $default if @_ > 1;
-    my $s = $self->mime_attr('content-type') ||
-       $self->{MIH_DefaultType} ||
-       'text/plain';
-    # avoid [perl #87336] bug, lc laundering tainted data
-    return lc($s)  if $] <= 5.008 || $] >= 5.014;
-    $s =~ tr/A-Z/a-z/;
-    $s;
+    lc($self->mime_attr('content-type') || 
+       $self->{MIH_DefaultType} || 
+       'text/plain');
 }
 
 #------------------------------
@@ -850,26 +583,28 @@ sub mime_type {
 =item multipart_boundary
 
 I<Instance method.>
-If this is a header for a multipart message, return the
+If this is a header for a multipart message, return the 
 "encapsulation boundary" used to separate the parts.  The boundary
 is returned exactly as given in the C<Content-type:> field; that
 is, the leading double-hyphen (C<-->) is I<not> prepended.
 
-Well, I<almost> exactly... this passage from RFC 2046 dictates
+Well, I<almost> exactly... this passage from RFC-1521 dictates
 that we remove any trailing spaces:
 
-   If a boundary appears to end with white space, the white space
+   If a boundary appears to end with white space, the white space 
    must be presumed to have been added by a gateway, and must be deleted.
 
 Returns undef (B<not> the empty string) if either the message is not
-multipart or if there is no specified boundary.
+multipart, if there is no specified boundary, or if the boundary is
+illegal (e.g., if it is empty after all trailing whitespace has been
+removed).
 
 =cut
 
 sub multipart_boundary {
     my $self = shift;
     my $value =  $self->mime_attr('content-type.boundary');
-    (!defined($value)) ? undef : $value;
+    (!defined($value) or $value eq '') ? undef : $value;
 }
 
 #------------------------------
@@ -878,30 +613,26 @@ sub multipart_boundary {
 
 I<Instance method.>
 Return the recommended external filename.  This is used when
-extracting the data from the MIME stream.  The filename is always
-returned as a string in Perl's internal format (the UTF8 flag may be on!)
+extracting the data from the MIME stream.
 
 Returns undef if no filename could be suggested.
 
 =cut
 
-sub recommended_filename
-{
-	my $self = shift;
+sub recommended_filename {
+    my $self = shift;
+    my $value;
 
-	# Try these headers in order, taking the first defined,
-	# non-blank one we find.
-	my $wd = supported MIME::WordDecoder 'UTF-8';
-	foreach my $attr_name ( qw( content-disposition.filename content-type.name ) ) {
-		my $value = $self->mime_attr( $attr_name );
-		if ( defined $value
-		    && $value ne ''
-		    && $value =~ /\S/ ) {
-			return $wd->decode($value);
-		}
-	}
+    ### Start by trying to get 'filename' from the 'content-disposition':
+    $value = $self->mime_attr('content-disposition.filename');
+    return $value if (defined($value) and $value ne '');
 
-	return undef;
+    ### No?  Okay, try to get 'name' from the 'content-type':
+    $value = $self->mime_attr('content-type.name');
+    return $value if (defined($value) and $value ne '');
+
+    ### Sorry:
+    undef;
 }
 
 #------------------------------
@@ -911,17 +642,6 @@ sub recommended_filename
 =cut
 
 
-#------------------------------
-#
-# tweak_FROM_parsing
-#
-# DEPRECATED.  Use the inherited mail_from() class method now.
-
-sub tweak_FROM_parsing {
-    my $self = shift;
-    usage "deprecated.  Use mail_from() instead.";
-    $self->mail_from(@_);
-}
 
 
 __END__
@@ -945,16 +665,18 @@ I quote from Achim Bohnet, who gave feedback on v.1.9 (I think
 he's using the word "header" where I would use "field"; e.g.,
 to refer to "Subject:", "Content-type:", etc.):
 
-    There is also IMHO no requirement [for] MIME::Heads to look
-    like [email] headers; so to speak, the MIME::Head [simply stores]
+    There is also IMHO no requirement [for] MIME::Heads to look 
+    like [email] headers; so to speak, the MIME::Head [simply stores] 
     the attributes of a complex object, e.g.:
 
         new MIME::Head type => "text/plain",
                        charset => ...,
                        disposition => ..., ... ;
 
-I agree in principle, but (alas and dammit) RFC 2045 says otherwise.
-RFC 2045 [MIME] headers are a syntactic subset of RFC-822 [email] headers.
+I agree in principle, but (alas and dammit) RFC-1521 says otherwise.
+RFC-1521 [MIME] headers are a syntactic subset of RFC-822 [email] headers.
+Perhaps a better name for these modules would be RFC1521:: instead of
+MIME::, but we're a little beyond that stage now.
 
 In my mind's eye, I see an abstract class, call it MIME::Attrs, which does
 what Achim suggests... so you could say:
@@ -965,33 +687,33 @@ what Achim suggests... so you could say:
 
 We could even make it a superclass of MIME::Head: that way, MIME::Head
 would have to implement its interface, I<and> allow itself to be
-initialized from a MIME::Attrs object.
+initiallized from a MIME::Attrs object.
 
-However, when you read RFC 2045, you begin to see how much MIME information
+However, when you read RFC-1521, you begin to see how much MIME information
 is organized by its presence in particular fields.  I imagine that we'd
-begin to mirror the structure of RFC 2045 fields and subfields to such
+begin to mirror the structure of RFC-1521 fields and subfields to such 
 a degree that this might not give us a tremendous gain over just
 having MIME::Head.
 
 
-=item Why all this "occurrence" and "index" jazz?  Isn't every field unique?
+=item Why all this "occurence" and "index" jazz?  Isn't every field unique?
 
 Aaaaaaaaaahh....no.
 
 Looking at a typical mail message header, it is sooooooo tempting to just
-store the fields as a hash of strings, one string per hash entry.
-Unfortunately, there's the little matter of the C<Received:> field,
-which (unlike C<From:>, C<To:>, etc.) will often have multiple
-occurrences; e.g.:
+store the fields as a hash of strings, one string per hash entry.  
+Unfortunately, there's the little matter of the C<Received:> field, 
+which (unlike C<From:>, C<To:>, etc.) will often have multiple 
+occurences; e.g.:
 
     Received: from gsfc.nasa.gov by eryq.pr.mcs.net  with smtp
-        (Linux Smail3.1.28.1 #5) id m0tStZ7-0007X4C;
+        (Linux Smail3.1.28.1 #5) id m0tStZ7-0007X4C; 
 	 Thu, 21 Dec 95 16:34 CST
-    Received: from rhine.gsfc.nasa.gov by gsfc.nasa.gov
-	 (5.65/Ultrix3.0-C) id AA13596;
+    Received: from rhine.gsfc.nasa.gov by gsfc.nasa.gov 
+	 (5.65/Ultrix3.0-C) id AA13596; 
 	 Thu, 21 Dec 95 17:20:38 -0500
-    Received: (from eryq@localhost) by rhine.gsfc.nasa.gov
-	 (8.6.12/8.6.12) id RAA28069;
+    Received: (from eryq@localhost) by rhine.gsfc.nasa.gov 
+	 (8.6.12/8.6.12) id RAA28069; 
 	 Thu, 21 Dec 1995 17:27:54 -0500
     Date: Thu, 21 Dec 1995 17:27:54 -0500
     From: Eryq <eryq@rhine.gsfc.nasa.gov>
@@ -1002,30 +724,31 @@ occurrences; e.g.:
 The C<Received:> field is used for tracing message routes, and although
 it's not generally used for anything other than human debugging, I
 didn't want to inconvenience anyone who actually wanted to get at that
-information.
+information.  
 
 I also didn't want to make this a special case; after all, who
-knows what other fields could have multiple occurrences in the
+knows what other fields could have multiple occurences in the
 future?  So, clearly, multiple entries had to somehow be stored
-multiple times... and the different occurrences had to be retrievable.
+multiple times... and the different occurences had to be retrievable.
 
 =back
 
-=head1 SEE ALSO
-
-L<Mail::Header>, L<Mail::Field>, L<MIME::Words>, L<MIME::Tools>
 
 =head1 AUTHOR
 
 Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
-Dianne Skoll (dianne@skoll.ca)
 
-All rights reserved.  This program is free software; you can redistribute
+All rights reserved.  This program is free software; you can redistribute 
 it and/or modify it under the same terms as Perl itself.
 
-The more-comprehensive filename extraction is courtesy of
+The more-comprehensive filename extraction is courtesy of 
 Lee E. Brotzman, Advanced Data Solutions.
 
+
+=head1 VERSION
+
+$Revision: 6.107 $ $Date: 2003/06/06 23:41:45 $
+
 =cut
 
 1;
